@@ -10,10 +10,10 @@
 !                                                                    !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-Subroutine extend1(n,k,z,z1)
+Subroutine extend1(n, k, z, z1)
 
-  INTEGER :: n,k
-  INTEGER :: z(0:600,0:600),z1(0:600,0:600)
+  INTEGER :: n, k
+  INTEGER :: z(0:n, 0:n), z1(0:(n+2*k), 0:(n+2*k))
 
   do i=k,k+n
      do j=k,k+n
